<?php 
/* 
 * Genesis Sermons CPT
 * 
 * This plugin creates a Custom Post Type for churches to use to display their latest sermons 
 * in a Wordpress web site. This plugin does require the Genesis framework (http://studiopress.com) . 
 * 
 * @package           Genesis_Sermons_CPT
 * @author            Chuck Smith
 * @license           GPL-2.0+
 * @link              http://www.polishedwp.com
 * @copyright         2016 Chuck Smith
 *
 * Plugin Name:       Genesis Sermons CPT
 * Plugin URI:        https://github.com/polishedwp/genesis-sermons-cpt
 * Description:       Adds a custom post type for Sermons to any Genesis Child Theme.
 * Version:           0.4.3
 * Author:            Chuck Smith
 * Author URI:        http://www.polishedwp.com
 * Text Domain:       genesis-sermons-cpt
 * License:           GPL-2.0+
 * License URI:       http://www.gnu.org/licenses/gpl-2.0.txt
 * Text Domain:       genesis-communities-cpt
 * Domain Path:       /languages/
 * Function prefix:   scpt_
 * GitHub Plugin URI: https://github.com/polishedwp/genesis-sermons-cpt
 * GitHub Branch:     master
 */ 

/*
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License, version 2, as 
    published by the Free Software Foundation.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
*/


// If this file is called directly, abort.
if ( ! defined( 'WPINC' ) ) {
	die;
}

/**
 * Defining Genesis Sermons CPT constants
 *
 * @since 0.3.0
 */

if( !defined( 'SCPT_VERSION' ) )define( 'SCPT_VERSION', '0.4' );
if( !defined( 'SCPT_BASE_FILE' ) )define( 'SCPT_BASE_FILE', __FILE__ );
if( !defined( 'SCPT_BASE_DIR' ) )define( 'SCPT_BASE_DIR', dirname( SCPT_BASE_FILE ) );
if( !defined( 'SCPT_PLUGIN_URL' ) )define( 'SCPT_PLUGIN_URL', plugin_dir_url( __FILE__ ) );
if( !defined( 'SCPT_PLUGIN_PATH' ) )define( 'SCPT_PLUGIN_PATH', plugin_dir_path( __FILE__ ) );

/**
 * Checks for activated Genesis Framework and its minimum version before allowing plugin to activate
 *
 * @author Nathan Rice, Remkus de Vries, Rian Rietveld, and adjusted for this plugin
 * @uses scpt_activation_check()
 * @since 0.2.0
 */

function scpt_activation_check() {
    
    // Find Genesis Theme Data
    $theme                   = wp_get_theme( 'genesis' );
    
    // Get the version
    $version                 = $theme->get( 'Version' );
   
    // Set what we consider the minimum Genesis version
    $minimum_genesis_version = '2.1.2';
    
    // Restrict activation to only when the Genesis Framework is activated
    if( basename( get_template_directory() ) != 'genesis' ) {
        deactivate_plugins( plugin_basename( __FILE__ ) );
        
        // Deactivate ourself
        wp_die( sprintf( __( 'This plugin requires that you have installed the %1$sGenesis Framework version %2$s%3$s or greater.', SCPT_DOMAIN ), '<a href="http://studiopress.com">', '</a>', $minimum_genesis_version ) );
    }
    
    // Set a minimum version of the Genesis Framework to be activated on
    if( version_compare( $version, $minimum_genesis_version, '<' ) ) {
        deactivate_plugins( plugin_basename( __FILE__ ) );
        
        // Deactivate ourself
        wp_die( sprintf( __( 'Oops.. you need to update to the latest version of the %1$sGenesis Framework version %2$s%3$s or greater to install this plugin.', SCPT_DOMAIN ), '<a href="http://studiopress.com">', '</a>', $minimum_genesis_version ) );
    }
}
register_deactivation_hook( __FILE__, 'scpt_myplugin_deactivate' );

function scpt_myplugin_deactivate() {
    flush_rewrite_rules();
}

///flush the permalinks - ref - https://codex.wordpress.org/Function_Reference/register_post_type#Flushing_Rewrite_on_Activation


function my_rewrite_flush() {
    // First, we "add" the custom post type via the above written function.
    // Note: "add" is written with quotes, as CPTs don't get added to the DB,
    // They are only referenced in the post_type column with a post entry, 
    // when you add a post of this CPT.
    //create_custom_post_type();

    // ATTENTION: This is *only* done during plugin activation hook in this example!
    // You should *NEVER EVER* do this on every page load!!
    flush_rewrite_rules();
}
register_activation_hook( __FILE__, 'my_rewrite_flush' );

function scpt_myplugin_flush_rewrites() {
    
    // call your CPT function here (it should also be hooked into 'init')
    
    scpt_create_custom_post_type();
    my_rewrite_flush();
}

// Test to make sure that Genesis is still running
if ( 'genesis' !== basename( get_template_directory() ) ) {
     add_action( 'admin_init', 'scpt_deactivate' ) ;
     add_action( 'admin_notices', 'scpt_error_message' );
    return;
}

// If it is not running, let's deactivate ourselves.
function scpt_deactivate() {
      
      deactivate_plugins( plugin_basename( __FILE__ ) );
      flush_rewrite_rules();
}

// show the message why we deactivated.
function scpt_error_message() {

        $error = sprintf( __( 'Sorry, Genesis Sermon CPT works only with the Genesis Framework. It has been deactivated.', 'genesis-sermon-cpt' ) );

        if ( version_compare( PHP_VERSION, '5.3', '<' ) ) {
            $error = $error . sprintf(
                __( ' But since we\'re talking anyway, did you know that your server is running PHP version %1$s, which is outdated? You should ask your host to update that for you.', 'display-featured-image-genesis' ),
                PHP_VERSION
            );
        }
        echo '<div class="error"><p>' . esc_attr( $error ) . '</p></div>';

        if ( isset( $_GET['activate'] ) ) {
            unset( $_GET['activate'] );
        }

}
/*
 * Future Versions will add a settings interface for entering 
 * Series, Speaker, Scripture, and Topics instead of standard WP 
 * Taxonomy admin widgets boxes.
 */

// Register the 'Sermons' custom post type
add_action ('init', 'create_sermon_post_type');
function create_sermon_post_type() {
	$labels = array(
		'name' => _x( 'Sermons', 'post type general name' ),
		'singular_name' => _x( 'Sermon', 'post type singular name' ),
		'add_new' => _x( 'Add New Sermon', 'sermon' ),
		'add_new_item' => __( 'Add New Sermon' ),
		'edit' => __( 'Edit' ),
		'edit_item' => __( 'Edit Sermon' ),
		'new_item' => __( 'New Sermon' ),
		'view' => __( 'View Sermon' ),
		'view_item' => __( 'View Sermon' ),
		'search_items' => __( 'Search Sermons' ),
		'not_found' => __( 'No sermons found' ),
		'not_found_in_trash' => __( 'No sermons found in Trash' ),
		'parent' => __( 'Parent Sermon' ),
		'menu_name' => 'Sermons'
	);
	$args = array(
		'labels' => $labels,
		'description' => __('Listen to sermons preached at Wesley UMC.'),
		'menu_position' => null,
		'has_archive' => true,
		'hierarchical' => false,
                // 'has_archive' => true,
		'query_var' => true,
		'public' => true,
		'rewrite' => array( 'slug' => 'sermons' ),
		'taxonomies' => array( 'series', 'speaker', 'passage', 'topic'),
                'supports' => array( 
                    'title',
                    'editor',
                    'excerpt',
                    'thumbnail',
                    'genesis-seo',
                    'genesis-layouts',
                    'genesis-simple-sidebars',
                    'genesis-cpt-archives-settings' ),
		'can_export' => true,
		'permalink_epmask' => EP_PERMALINK
	);
	register_post_type( 'sermons', $args );
}

// Register Sermon taxonomies
add_action( 'init', 'create_sermon_taxonomies', 0 );
function create_sermon_taxonomies() {
	
	// Add Speaker taxonomy
	$labels = array(
		'name' => _x( 'Speakers', 'taxonomy general name' ),
		'singular_name' => _x( 'Speaker', 'taxonomy singular name' ),
		'search_items' =>  __( 'Search Speakers' ),
		'popular_items' => __( 'Popular Speakers' ),
		'all_items' => __( 'All Speakers' ),
		'parent_item' => null,
		'parent_item_colon' => null,
		'edit_item' => __( 'Edit Speaker' ), 
		'update_item' => __( 'Update Speaker' ),
		'add_new_item' => __( 'Add New Speaker' ),
		'new_item_name' => __( 'New Speaker Name' ),
		'separate_items_with_commas' => __( 'Separate speakers with commas' ),
		'add_or_remove_items' => __( 'Add or remove speakers' ),
		'choose_from_most_used' => __( 'Choose from the most used speakers' ),
		'menu_name' => __( 'Speakers' ),
	);
	$args = array(
		'hierarchical' => false,
		'labels' => $labels,
		'show_ui' => true,
		'query_var' => true,
		'rewrite' => array( 'slug' => 'speaker' )
	);
	register_taxonomy( 'speaker', 'sermons', $args );
        
        // Add Series taxonomy
	$labels = array(
		'name' => _x( 'Series', 'taxonomy general name' ),
		'singular_name' => _x( 'Series', 'taxonomy singular name' ),
		'search_items' =>  __( 'Search Series' ),
		'popular_items' => __( 'Popular Series' ),
		'all_items' => __( 'All Series' ),
		'parent_item' => null,
		'parent_item_colon' => null,
		'edit_item' => __( 'Edit Speaker' ), 
		'update_item' => __( 'Update Speaker' ),
		'add_new_item' => __( 'Add New Speaker' ),
		'new_item_name' => __( 'New Speaker Name' ),
		'separate_items_with_commas' => __( 'Separate series with commas' ),
		'add_or_remove_items' => __( 'Add or remove series' ),
		'choose_from_most_used' => __( 'Choose from the most used series' ),
		'menu_name' => __( 'Series' ),
	);
	$args = array(
		'hierarchical' => false,
		'labels' => $labels,
		'show_ui' => true,
                'show_admin_column' => true,
		'query_var' => true,
		'rewrite' => array( 'slug' => 'series' )
	);
	register_taxonomy( 'series', 'sermons', $args );
        
        // Add Passage taxonomy
	$labels = array(
		'name' => _x( 'Passage', 'taxonomy general name' ),
		'singular_name' => _x( 'Passage', 'taxonomy singular name' ),
		'search_items' =>  __( 'Search Passage' ),
		'popular_items' => __( 'Popular Passage' ),
		'all_items' => __( 'All Passage' ),
		'parent_item' => null,
		'parent_item_colon' => null,
		'edit_item' => __( 'Edit Passage' ), 
		'update_item' => __( 'Update Passage' ),
		'add_new_item' => __( 'Add New Speaker' ),
		'new_item_name' => __( 'New Speaker Name' ),
		'separate_items_with_commas' => __( 'Separate passages with commas' ),
		'add_or_remove_items' => __( 'Add or remove passages' ),
		'choose_from_most_used' => __( 'Choose from the most used series' ),
		'menu_name' => __( 'Passage' ),
	);
	$args = array(
		'hierarchical' => false,
		'labels' => $labels,
		'show_ui' => true,
                'show_admin_column' => true,
		'query_var' => true,
		'rewrite' => array( 'slug' => 'passage' )
	);
	register_taxonomy( 'passage', 'sermons', $args );
        
        // Add Topic taxonomy
	$labels = array(
		'name' => _x( 'Topic', 'taxonomy general name' ),
		'singular_name' => _x( 'Topic', 'taxonomy singular name' ),
		'search_items' =>  __( 'Search Topics' ),
		'popular_items' => __( 'Popular Topics' ),
		'all_items' => __( 'All Topics' ),
		'parent_item' => null,
		'parent_item_colon' => null,
		'edit_item' => __( 'Edit Topic' ), 
		'update_item' => __( 'Update Topic' ),
		'add_new_item' => __( 'Add New Topic' ),
		'new_item_name' => __( 'New Topic' ),
		'separate_items_with_commas' => __( 'Separate topics with commas' ),
		'add_or_remove_items' => __( 'Add or remove topics' ),
		'choose_from_most_used' => __( 'Choose from the most used topics' ),
		'menu_name' => __( 'Topics' ),
	);
	$args = array(
		'hierarchical' => false,
		'labels' => $labels,
		'show_ui' => true,
                'show_admin_column' => true,
		'query_var' => true,
		'rewrite' => array( 'slug' => 'topic' )
	);
	register_taxonomy( 'topic', 'sermons', $args );
}

/*
 * Credit: Sridhar Kataham
 * URI: https://sridharkatakam.com/single-archive-templates-custom-post-type-genesis/ 
 * Description: Function to rewrite post-meta of CPT post
 */
add_filter( 'genesis_post_info', 'custom_post_info' );
function custom_post_info ( $post_info ) {
	if ( is_singular( 'sermons' ) || is_post_type_archive ( 'sermons' ) || is_tax('series')){
            $post_info = '[post_date] [post_terms taxonomy="speaker" before=""] [post_terms taxonomy="series" before=""] [post_terms taxonomy="passage" before=""]';
            }
        return $post_info;
}

/*
 * Future versions will include a custon sidebar for single-post template. 
 * 
 */
